@@ -4,7 +4,7 @@ use utf8;
 use strict;
 use warnings;
 
-$Acme::Glue::VERSION = "2022.04";
+$Acme::Glue::VERSION = "2022.11";
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Acme::Glue - A placeholder module for code accompanying a Perl photo project
 
 =head1 VERSION
 
-2021.08
+2022.11
 
 =head1 DESCRIPTION
 
@@ -100,6 +100,24 @@ Here are the snippets that accompany the photo project
     .
     __END__
 
+=head2 LEEJO (example from "How Perl Saved the Human Genome Project" complete with syntax error)
+
+    use Boulder::Stream; 
+    $stream = new Boulder::Stream; 
+    while ($record=$stream->read_record('NAME','SEQUENCE')) {
+        $name = $record->get('NAME'); 
+        $sequence = $record->get('SEQUENCE'); 
+
+        ...continue processing...
+
+        $record->add(QUALITY_CHECK=>"OK|); 
+        $stream->write_record($record); 
+    } 
+
+=head2 LEEJO (quine - a program that prints itself out)
+
+    $_=q(print"\$_=q($_);eval;");eval;
+
 =head2 SLU (MAZE.BAS)
 
     10 PRINT CHR$(205.5+RND(1));:GOTO 10
